@@ -1,9 +1,8 @@
-
-from sympy.utilities.iterables import is_sequence
-from sympy.external import import_module
 from itertools import cycle
 from spb.series import BaseSeries
 from spb.backends.utils import convert_colormap
+from sympy.utilities.iterables import is_sequence
+from sympy.external import import_module
 
 
 class Plot:
@@ -147,7 +146,7 @@ class Plot:
        >>> plot3d(
        ...     (cos(x**2 + y**2), (x, -2, 0), (y, -2, 2)),
        ...     (cos(x**2 + y**2), (x, 0, 2), (y, -2, 2)),
-       ...     backend=MBchild, n1=25, n2=50)
+       ...     backend=MBchild, n1=25, n2=50, use_cm=True)
 
 
     See also
@@ -424,6 +423,8 @@ class Plot:
         return self._do_sum(other)
 
     def __radd__(self, other):
+        if other == 0:
+            return self
         return other._do_sum(self)
 
     def _do_sum(self, other):
