@@ -1,9 +1,9 @@
+import itertools
 from spb.defaults import cfg
 from spb.backends.base_backend import Plot
 from spb.backends.utils import compute_streamtubes
 from sympy import latex
 from sympy.external import import_module
-import itertools
 
 # Global variable
 # Set to False when running tests / doctests so that the plots don't show.
@@ -68,38 +68,19 @@ class MatplotlibBackend(Plot):
         * ``'center'``: center of the current plot area.
         * ``'auto'``: the intersection point is automatically computed.
 
-    contour_kw : dict, optional
-        A dictionary of keywords/values which is passed to Matplotlib's
-        contour/contourf function to customize the appearance.
-        Refer to [#fn1]_ to learn more about customization.
-
-    image_kw : dict, optional
-        A dictionary of keywords/values which is passed to Matplotlib's
-        imshow function to customize the appearance.
-        Refer to [#fn2]_ to learn more about customization.
-
-    line_kw : dict, optional
+    rendering_kw : dict, optional
         A dictionary of keywords/values which is passed to Matplotlib's plot
-        functions to customize the appearance of the lines.
+        functions to customize the appearance of lines, surfaces, images,
+        contours, quivers, streamlines...
         To learn more about customization:
 
-        * Refer to [#fn3]_ if the plot is using solid colors.
-        * Refer to [#fn4]_ if the plot is using color maps.
-
-    quiver_kw : dict, optional
-        A dictionary of keywords/values which is passed to Matplotlib's quivers
-        function to customize the appearance.
-        Refer to [#fn5]_ to learn more about customization.
-
-    surface_kw : dict, optional
-        A dictionary of keywords/values which is passed to Matplotlib's
-        surface function to customize the appearance.
-        Refer to [#fn6]_ to learn more about customization.
-
-    stream_kw : dict, optional
-        A dictionary of keywords/values which is passed to Matplotlib's
-        streamplot function to customize the appearance.
-        Refer to [#fn7]_ to learn more about customization.
+        * Refer to [#fn1]_ to customize contour plots.
+        * Refer to [#fn2]_ to customize image plots.
+        * Refer to [#fn3]_ to customize solid line plots.
+        * Refer to [#fn4]_ to customize colormap-based line plots.
+        * Refer to [#fn5]_ to customize quiver plots.
+        * Refer to [#fn6]_ to customize surface plots.
+        * Refer to [#fn7]_ to customize stramline plots.
 
     use_cm : boolean, optional
         If True, apply a color map to the mesh/surface or parametric lines.
@@ -179,7 +160,9 @@ class MatplotlibBackend(Plot):
 
     def _set_piecewise_color(self, s, color):
         """Set the color to the given series"""
-        s.rendering_kw["color"] = color
+        if "color" not in s.rendering_kw:
+            # only set the color if the user didn't do that already
+            s.rendering_kw["color"] = color
 
     @staticmethod
     def _do_sum_kwargs(p1, p2):
@@ -362,7 +345,8 @@ class MatplotlibBackend(Plot):
                         x, y, param = s.get_data()
                     else:
                         x, y = s.get_data()
-                    lkw = dict(label=s.get_label(self._use_latex), color=next(self._cl))
+                    color = next(self._cl) if s.line_color is None else s.line_color
+                    lkw = dict(label=s.get_label(self._use_latex), color=color)
                     if s.is_point:
                         lkw["marker"] = "o"
                         lkw["linestyle"] = "None"
@@ -396,13 +380,13 @@ class MatplotlibBackend(Plot):
                         self._add_handle(i, c)
                     else:
                         lkw["label"] = s.get_label(self._use_latex)
-                        kw = merge({}, lkw, s.rendering_kw)
+                        kw = merge({}, lkw, s.rendering_kw, {} if s.line_color is None else {"color": s.line_color})
                         l = self.ax.plot(x, y, z, **kw)
                         self._add_handle(i, l)
                 else:
                     # 3D points
                     lkw["label"] = s.get_label(self._use_latex)
-                    lkw["color"] = next(self._cl)
+                    lkw["color"] = next(self._cl) if s.line_color is None else s.line_color
                     kw = merge({}, lkw, s.rendering_kw)
                     l = self.ax.scatter(x, y, z, **kw)
                     self._add_handle(i, l)
@@ -413,10 +397,10 @@ class MatplotlibBackend(Plot):
             elif (s.is_3Dsurface and (not s.is_domain_coloring) and (not s.is_implicit)):
                 if not s.is_parametric:
                     x, y, z = self.series[i].get_data()
-                    facecolors = s.color_func(x, y, z)
+                    facecolors = s.eval_color_func(x, y, z)
                 else:
                     x, y, z, u, v = self.series[i].get_data()
-                    facecolors = s.color_func(x, y, z, u, v)
+                    facecolors = s.eval_color_func(x, y, z, u, v)
                 skw = dict(rstride=1, cstride=1, linewidth=0.1)
                 norm, cmap = None, None
                 if s.use_cm:
@@ -424,13 +408,15 @@ class MatplotlibBackend(Plot):
                     cmap = next(self._cm)
                     skw["cmap"] = cmap
                 else:
-                    skw["color"] = next(self._cl)
+                    skw["color"] = next(self._cl) if s.surface_color is None else s.surface_color
 
                 kw = merge({}, skw, s.rendering_kw)
                 if s.use_cm:
                     # facecolors must be computed here because s.rendering_kw
                     # might have its own cmap
                     cmap = kw["cmap"]
+                    if isinstance(cmap, str):
+                        cmap = self.cm.get_cmap(cmap)
                     kw["facecolors"] = cmap(norm(facecolors))
                 c = self.ax.plot_surface(x, y, z, **kw)
                 is_cb_added = self._add_colorbar(c, s.get_label(self._use_latex), s.use_cm, norm=norm, cmap=cmap)
@@ -855,17 +841,20 @@ class MatplotlibBackend(Plot):
                 elif s.is_3Dsurface and (not s.is_domain_coloring) and (not s.is_implicit):
                     if not s.is_parametric:
                         x, y, z = self.series[i].get_data()
-                        facecolors = s.color_func(x, y, z)
+                        facecolors = s.eval_color_func(x, y, z)
                     else:
                         x, y, z, u, v = self.series[i].get_data()
-                        facecolors = s.color_func(x, y, z, u, v)
+                        facecolors = s.eval_color_func(x, y, z, u, v)
                     # TODO: by setting the keyword arguments, somehow the
                     # update becomes really really slow.
                     kw, is_cb_added, cax = self._handles[i][1:]
 
                     if is_cb_added:
                         norm = self.Normalize(vmin=np.amin(facecolors), vmax=np.amax(facecolors))
-                        kw["facecolors"] = kw["cmap"](norm(facecolors))
+                        cmap = kw["cmap"]
+                        if isinstance(cmap, str):
+                            cmap = self.cm.get_cmap(cmap)
+                        kw["facecolors"] = cmap(norm(facecolors))
                     self._handles[i][0].remove()
                     self._handles[i][0] = self.ax.plot_surface(
                         x, y, z, **kw)
