@@ -1,25 +1,19 @@
-from sympy.core.containers import Tuple
-from sympy.functions.elementary.miscellaneous import sqrt
-from sympy.functions.elementary.complexes import re, im, arg
-from sympy.core.expr import Expr
-from sympy.core.symbol import Dummy, symbols
-from sympy.core.numbers import I
-from spb.defaults import cfg
-import warnings
-
+from spb.defaults import cfg, TWO_D_B, THREE_D_B
+from spb.functions import _set_labels
 from spb.series import (
-    LineOver1DRangeSeries,
-    ComplexSurfaceBaseSeries,
-    ComplexInteractiveBaseSeries,
-    ComplexPointSeries,
-    ComplexPointInteractiveSeries,
-    _set_discretization_points,
-    SurfaceOver2DRangeSeries,
-    InteractiveSeries
+    LineOver1DRangeSeries, ComplexSurfaceBaseSeries,
+    ComplexInteractiveBaseSeries, ComplexPointSeries,
+    ComplexPointInteractiveSeries, SurfaceOver2DRangeSeries,
+    InteractiveSeries, _set_discretization_points
+)
+from spb.utils import (
+    _unpack_args, _instantiate_backend, _plot_sympify, _check_arguments,
+    _is_range
 )
 from spb.vectors import plot_vector
-from spb.utils import _plot_sympify, _check_arguments, _is_range
-from spb.defaults import TWO_D_B, THREE_D_B
+from sympy import latex, Tuple, sqrt, re, im, arg, Expr, Dummy, symbols, I
+import warnings
+
 
 # NOTE:
 # * `abs` refers to the absolute value;
@@ -27,22 +21,10 @@ from spb.defaults import TWO_D_B, THREE_D_B
 # * `absarg` refers to the absolute value and argument, which will be used to
 #   create "domain coloring" plots.
 
-
-def _get_labels(args, kwargs):
-    # implement the label keyword argument
-    # NOTE: this function is a workaround until a better integration is
-    # achieved between iplot and all other plotting functions.
-    labels = kwargs.pop("label", [])
-    if (len(labels) > 0) and (len(labels) != len(args)):
-        raise ValueError("The number of labels must be equals to the "
-            "number of expressions being plotted.\nReceived "
-            "{} expressions and {} labels".format(len(args), len(labels)))
-    if len(labels) == 0:
-        labels = [None] * len(args)
-    return labels
-
-
 def _build_series(*args, interactive=False, **kwargs):
+    global_labels = kwargs.pop("label", [])
+    global_rendering_kw = kwargs.pop("rendering_kw", None)
+
     series = []
     # apply the user-specified function to the expression
     #   keys: the user specified keyword arguments
@@ -70,25 +52,26 @@ def _build_series(*args, interactive=False, **kwargs):
     if all([hasattr(a, "is_complex") and a.is_complex for a in args]):
         # args is a list of complex numbers
         cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
-        labels = _get_labels(args, kwargs)
-        for a, lbl in zip(args, labels):
-            if lbl is None:
-                lbl = str(a)
-            series.append(cls([a], lbl, **kwargs))
+        for a in args:
+            series.append(cls([a], "", **kwargs))
     elif (
         (len(args) > 0)
         and all([isinstance(a, (list, tuple, Tuple)) for a in args])
         and all([len(a) > 0 for a in args])
         and all([isinstance(a[0], (list, tuple, Tuple)) for a in args])
     ):
-        # args is a list of tuples of the form (list, label) where list
-        # contains complex points
+        # args is a list of tuples of the form (list, label, rendering_kw)
+        # where list contains complex points
         cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
-        labels = _get_labels(args, kwargs)
-        for a, lbl in zip(args, labels):
-            if lbl is None:
-                lbl = a[-1]
-            series.append(cls(a[0], lbl, **kwargs))
+        for a in args:
+            expr, ranges, label, rkw = _unpack_args(*a)
+            # Complex points do not require ranges. However, if 3 complex
+            # points are given inside a list, _unpack_args will see them as a
+            # range.
+            expr = expr or ranges
+            kw = kwargs.copy()
+            kw["rendering_kw"] = rkw
+            series.append(cls(expr[0], label, **kw))
     elif (
         (len(args) > 0)
         and all([isinstance(a, (list, tuple, Tuple)) for a in args])
@@ -96,11 +79,8 @@ def _build_series(*args, interactive=False, **kwargs):
     ):
         # args is a list of lists
         cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
-        labels = _get_labels(args, kwargs)
-        for a, lbl in zip(args, labels):
-            if lbl is None:
-                lbl = ""
-            series.append(cls(a, lbl, **kwargs))
+        for a in args:
+            series.append(cls(a, "", **kwargs))
     else:
         new_args = []
 
@@ -140,12 +120,12 @@ def _build_series(*args, interactive=False, **kwargs):
                 # plotting a single expression
                 add_series(args)
 
-        labels = _get_labels(new_args, kwargs)
         params = kwargs.get("params", dict())
-        for a, lbl in zip(new_args, labels):
-            expr, ranges, label = a[0], a[1:-1], a[-1]
-            if lbl is not None:
-                label = lbl
+        for a in new_args:
+            expr, ranges, label, rend_kw = a[0], a[1:-2], a[-2], a[-1]
+
+            kw = kwargs.copy()
+            kw["rendering_kw"] = rend_kw
 
             # From now on we are dealing with a function of one variable.
             # ranges need to contain complex numbers
@@ -161,7 +141,7 @@ def _build_series(*args, interactive=False, **kwargs):
             if expr.is_complex and (len(fs) == 0):
                 # complex number with its own label
                 cls = ComplexPointSeries if not interactive else ComplexPointInteractiveSeries
-                series.append(cls([expr], label, **kwargs))
+                series.append(cls([expr], label, **kw))
 
             else:
                 # NOTE: as a design choice, a complex function will create one
@@ -173,7 +153,6 @@ def _build_series(*args, interactive=False, **kwargs):
                 # and backend.data, making it easier to work with iplot
                 # (backend._update_interactive).
 
-                kw = kwargs.copy()
                 absarg = kw.pop("absarg", True)
                 real = kw.pop("real", False)
                 imag = kw.pop("imag", False)
@@ -196,7 +175,6 @@ def _build_series(*args, interactive=False, **kwargs):
                     # 2D domain coloring or 3D plots
                     cls = ComplexSurfaceBaseSeries if not interactive else ComplexInteractiveBaseSeries
                     kw.setdefault("coloring", cfg["complex"]["coloring"])
-
                     def add_series(flag, key):
                         if flag:
                             kw2 = kw.copy()
@@ -212,13 +190,23 @@ def _build_series(*args, interactive=False, **kwargs):
                 add_series(_abs, "abs")
                 add_series(_arg, "arg")
 
+    _set_labels(series, global_labels, global_rendering_kw)
     return series
 
 
-def _plot_complex(*args, show=True, **kwargs):
+def _plot_complex(*args, **kwargs):
     """Create the series and setup the backend."""
     args = _plot_sympify(args)
     kwargs = _set_discretization_points(kwargs, ComplexSurfaceBaseSeries)
+    kwargs["is_complex"] = True
+
+    if kwargs.get("params", None):
+        # NOTE: the iplot module is really slow to load, so let's load it
+        # only when it is necessary
+        from spb.interactive import iplot
+        kwargs["is_interactive"] = True
+        args = _check_arguments(args, 1, 1, **kwargs)
+        return iplot(*args, **kwargs)
 
     series = _build_series(*args, **kwargs)
     if len(series) == 0:
@@ -229,32 +217,40 @@ def _plot_complex(*args, show=True, **kwargs):
     else:
         Backend = kwargs.pop("backend", TWO_D_B)
 
-    if all(
-        isinstance(s, (SurfaceOver2DRangeSeries, InteractiveSeries)) for s in series
-    ):
-        # function of 2 variables
-        if kwargs.get("xlabel", None) is None:
-            if len(series) > 0:
-                kwargs["xlabel"] = str(series[0].var_x)
-        if kwargs.get("ylabel", None) is None:
-            if len(series) > 0:
-                kwargs["ylabel"] = str(series[0].var_y)
-        # do not set anything for zlabel since it could be f(x,y) or
-        # abs(f(x, y)) or something else
-    elif all(not s.is_parametric for s in series):
+    _set_axis_labels(series, kwargs)
+
+    return _instantiate_backend(Backend, *series, **kwargs)
+
+
+def _set_axis_labels(series, kwargs):
+    """Set the axis labels for the plot, depending on the series being
+    visualized.
+    """
+    if all(s.is_domain_coloring or s.is_3Dsurface or isinstance(s, ComplexPointSeries) for s in series):
         # when plotting real/imaginary or domain coloring/3D plots, the
         # horizontal axis is the real, the vertical axis is the imaginary
         if kwargs.get("xlabel", None) is None:
             kwargs["xlabel"] = "Re"
         if kwargs.get("ylabel", None) is None:
             kwargs["ylabel"] = "Im"
-        if kwargs.get("zlabel", None) is None:
+        if kwargs.get("zlabel", None) is None and any(s.is_domain_coloring for s in series):
             kwargs["zlabel"] = "Abs"
-    else:
+    elif all(s.is_parametric for s in series):
         if kwargs.get("xlabel", None) is None:
             kwargs["xlabel"] = "Real"
         if kwargs.get("ylabel", None) is None:
             kwargs["ylabel"] = "Abs"
+    else:
+        var = series[0].var if not series[0].is_interactive else list(series[0].ranges.keys())[0]
+
+        if kwargs.get("xlabel", None) is None:
+            fx = lambda use_latex: var.name if not use_latex else latex(var)
+            kwargs.setdefault("xlabel", fx)
+        if kwargs.get("ylabel", None) is None:
+            wrap = lambda use_latex: "f(%s)" if not use_latex else r"f\left(%s\right)"
+            x = kwargs["xlabel"] if callable(kwargs["xlabel"]) else lambda use_latex: kwargs["xlabel"]
+            fy = lambda use_latex: wrap(use_latex) % x(use_latex)
+            kwargs.setdefault("ylabel", fy)
 
     if (kwargs.get("aspect", None) is None) and any(
         (s.is_complex and s.is_domain_coloring) or s.is_point for s in series
@@ -262,11 +258,6 @@ def _plot_complex(*args, show=True, **kwargs):
         # set aspect equal for 2D domain coloring or complex points
         kwargs.setdefault("aspect", "equal")
 
-    p = Backend(*series, **kwargs)
-    if show:
-        p.show()
-    return p
-
 
 def plot_real_imag(*args, **kwargs):
     """Plot the real part, the imaginary parts, the absolute value and the
@@ -291,8 +282,8 @@ def plot_real_imag(*args, **kwargs):
         `plot_real_imag(expr1, expr2, ..., range, **kwargs)`
     - Plotting multiple expressions with multiple ranges.
         `plot_real_imag((expr1, range1), (expr2, range2), ..., **kwargs)`
-    - Plotting multiple expressions with multiple ranges and custom labels.
-        `plot_real_imag((expr1, range1, label1), (expr2, range2, label2), ..., **kwargs)`
+    - Plotting multiple expressions with custom labels and rendering options.
+        `plot_real_imag((expr1, range1, label1, rendering_kw1), (expr2, range2, label2, rendering_kw2), ..., **kwargs)`
 
     Parameters
     ==========
@@ -318,6 +309,13 @@ def plot_real_imag(*args, **kwargs):
             legend. If none is provided, the string representation of the
             function will be used.
 
+        rendering_kw : dict, optional
+            A dictionary of keywords/values which is passed to the backend's
+            function to customize the appearance of lines. Refer to the
+            plotting library (backend) manual for more informations. Note that
+            the same options will be applied to all series generated for the
+            specified expression.
+
     abs : boolean, optional
         If True, plot the modulus of the complex function. Default to True.
 
@@ -365,10 +363,10 @@ def plot_real_imag(*args, **kwargs):
         If True, plot the imaginary part of the complex function.
         Default to True.
 
-    line_kw : dict, optional
-        A dictionary of keywords/values which is passed to the backend's
-        function to customize the appearance of the lines. Refer to the
-        plotting library (backend) manual for more informations.
+    label : list/tuple, optional
+        The labels to be shown in the legend. If not provided, the string
+        representation of `expr` will be used. The number of labels must be
+        equal to the number of series generated by the plotting function.
 
     loss_fn : callable or None
         The loss function to be used by the `adaptive` learner.
@@ -396,6 +394,19 @@ def plot_real_imag(*args, **kwargs):
         points in all directions. If a tuple is provided, it overrides
         `n1` and `n2`. It only works when `adaptive=False`.
 
+    params : dict
+        A dictionary mapping symbols to parameters. This keyword argument
+        enables the interactive-widgets plot, which doesn't support the
+        adaptive algorithm (meaning it will use ``adaptive=False``).
+        Learn more by reading the documentation of ``iplot``.
+
+    rendering_kw : dict or list of dicts, optional
+        A dictionary of keywords/values which is passed to the backend's
+        function to customize the appearance of lines. Refer to the
+        plotting library (backend) manual for more informations.
+        If a list of dictionaries is provided, the number of dictionaries must
+        be equal to the number of series generated by the plotting function.
+
     real : boolean, optional
         If True, plot the real part of the complex function. Default to True.
 
@@ -514,6 +525,17 @@ def plot_real_imag(*args, **kwargs):
        [0]: cartesian line: sqrt(sqrt(re(x)**2 + im(x)**2)*sin(atan2(im(x), re(x))/2)**2 + sqrt(re(x)**2 + im(x)**2)*cos(atan2(im(x), re(x))/2)**2) for x over (-3.0, 3.0)
        [1]: cartesian line: arg(sqrt(x)) for x over (-3.0, 3.0)
 
+    Interactive-widget plot. Refer to ``iplot`` documentation to learn more
+    about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       x, u = symbols("x, u")
+       plot_real_imag(sqrt(x) * exp(-u * x**2), (x, -3, 3),
+           params={u: (1, 0, 2)}, ylim=(-0.25, 2))
+
     3D plot of the real and imaginary part of a function over a complex range:
 
     .. plot::
@@ -538,6 +560,18 @@ def plot_real_imag(*args, **kwargs):
        Plot object containing:
        [0]: complex cartesian surface: sqrt(sqrt(re(x)**2 + im(x)**2)*sin(atan2(im(x), re(x))/2)**2 + sqrt(re(x)**2 + im(x)**2)*cos(atan2(im(x), re(x))/2)**2) for re(x) over (-3.0, 3.0) and im(x) over (-3.0, 3.0)
 
+    3D interactive-widget plot. Refer to ``iplot`` documentation to learn more
+    about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       x, u = symbols("x, u")
+       plot_real_imag(
+           sqrt(x) * exp(u * x), (x, -3-3j, 3+3j),
+           params={u: (0.5, 0, 1)}, n=25, threed=True)
+
     References
     ==========
 
@@ -546,7 +580,7 @@ def plot_real_imag(*args, **kwargs):
     See Also
     ========
 
-    plot_complex, plot_complex_list, plot_complex_vector
+    plot_complex, plot_complex_list, plot_complex_vector, iplot
 
     """
     kwargs["absarg"] = False
@@ -582,8 +616,8 @@ def plot_complex(*args, **kwargs):
         `plot_complex(expr1, expr2, ..., range, **kwargs)`
     - Plotting multiple expressions with multiple ranges.
         `plot_complex((expr1, range1), (expr2, range2), ..., **kwargs)`
-    - Plotting multiple expressions with multiple ranges and custom labels.
-        `plot_complex((expr1, range1, label1), (expr2, range2, label2), ..., **kwargs)`
+    - Plotting multiple expressions with custom labels and rendering options.
+        `plot_complex((expr1, range1, label1, rendering_kw1), (expr2, range2, label2, rendering_kw2), ..., **kwargs)`
 
     Parameters
     ==========
@@ -609,6 +643,12 @@ def plot_complex(*args, **kwargs):
             legend. If none is provided, the string representation of the
             function will be used.
 
+        rendering_kw : dict, optional
+            A dictionary of keywords/values which is passed to the backend's
+            function to customize the appearance of lines, surfaces or images.
+            Refer to the plotting library (backend) manual for more
+            informations.
+
     adaptive : bool, optional
         Attempt to create line plots by using an adaptive algorithm.
         Image and surface plots do not use an adaptive algorithm.
@@ -640,11 +680,6 @@ def plot_complex(*args, **kwargs):
         If not provided, the string representation of `expr` will be used.
         The number of labels must be  equal to the number of expressions.
 
-    line_kw : dict, optional
-        A dictionary of keywords/values which is passed to the backend's
-        function to customize the appearance of lines. Refer to the
-        plotting library (backend) manual for more informations.
-
     loss_fn : callable or None
         The loss function to be used by the `adaptive` learner.
         Possible values:
@@ -671,6 +706,19 @@ def plot_complex(*args, **kwargs):
         points in all directions. If a tuple is provided, it overrides
         `n1` and `n2`. It only works when `adaptive=False`.
 
+    params : dict
+        A dictionary mapping symbols to parameters. This keyword argument
+        enables the interactive-widgets plot, which doesn't support the
+        adaptive algorithm (meaning it will use ``adaptive=False``).
+        Learn more by reading the documentation of ``iplot``.
+
+    rendering_kw : dict or list of dicts, optional
+        A dictionary of keywords/values which is passed to the backend's
+        function to customize the appearance of lines, surfaces or images.
+        Refer to the plotting library (backend) manual for more informations.
+        If a list of dictionaries is provided, the number of dictionaries must
+        be equal to the number of series generated by the plotting function.
+
     show : boolean, optional
         Default to True, in which case the plot will be shown on the screen.
 
@@ -769,7 +817,6 @@ def plot_complex(*args, **kwargs):
        >>> from spb import plot_complex
        >>> x, y, z = symbols('x, y, z')
 
-
     Plot the modulus of a complex function colored by its magnitude:
 
     .. plot::
@@ -781,6 +828,18 @@ def plot_complex(*args, **kwargs):
        Plot object containing:
        [0]: absolute-argument line: cos(x) + I*sinh(x) for x over ((-2+0j), (2+0j))
 
+    Interactive-widget plot. Refer to ``iplot`` documentation to learn more
+    about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       x, u = symbols("x, u")
+       plot_complex(
+           exp(I * x) * I * sin(u * x), "f", (x, -5, 5),
+           params={u: (1, 0, 2)}, ylim=(-0.2, 1.2))
+
     Domain coloring plot. Note that it might be necessary to increase the
     number of discretization points in order to get a smoother plot:
 
@@ -794,6 +853,19 @@ def plot_complex(*args, **kwargs):
        Plot object containing:
        [0]: domain coloring: gamma(z) for re(z) over (-3.0, 3.0) and im(z) over (-3.0, 3.0)
 
+    Interactive-widget domain coloring plot. Refer to ``iplot`` documentation
+    to learn more about the ``params`` dictionary. Note that a too large
+    value of ``n`` will impact performance.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       x, u = symbols("x, u")
+       plot_complex(
+           gamma(u * z), (z, -3 - 3*I, 3 + 3*I),
+           coloring="b", n=250, grid=False, params={u: (1, 0, 2)})
+
     3D plot of the absolute value of a complex function colored by its
     argument:
 
@@ -820,7 +892,7 @@ def plot_complex(*args, **kwargs):
     See Also
     ========
 
-    plot_real_imag, plot_complex_list, plot_complex_vector
+    plot_real_imag, plot_complex_list, plot_complex_vector, iplot
 
     """
     kwargs["absarg"] = True
@@ -855,6 +927,13 @@ def plot_complex_list(*args, **kwargs):
             The name associated to the list of the complex numbers to be
             eventually shown on the legend. Default to empty string.
 
+        rendering_kw : dict, optional
+            A dictionary of keywords/values which is passed to the backend's
+            function to customize the appearance of lines. Refer to the
+            plotting library (backend) manual for more informations. Note that
+            the same options will be applied to all series generated for the
+            specified expression.
+
     aspect : (float, float) or str, optional
         Set the aspect ratio of the plot. The value depends on the backend
         being used. Read that backend's documentation to find out the
@@ -876,12 +955,20 @@ def plot_complex_list(*args, **kwargs):
     label : str or list/tuple, optional
         The name associated to the list of the complex numbers to be
         eventually shown on the legend. The number of labels must be equal to
-        the number of lists.
+        the number of series generated by the plotting function.
 
-    line_kw : dict, optional
+    params : dict
+        A dictionary mapping symbols to parameters. This keyword argument
+        enables the interactive-widgets plot, which doesn't support the
+        adaptive algorithm (meaning it will use ``adaptive=False``).
+        Learn more by reading the documentation of ``iplot``.
+
+    rendering_kw : dict or list of dicts, optional
         A dictionary of keywords/values which is passed to the backend's
         function to customize the appearance of lines. Refer to the
         plotting library (backend) manual for more informations.
+        If a list of dictionaries is provided, the number of dictionaries must
+        be equal to the number of series generated by the plotting function.
 
     show : boolean
         Default to True, in which case the plot will be shown on the screen.
@@ -960,10 +1047,29 @@ def plot_complex_list(*args, **kwargs):
        [0]: complex points (0.0, 0.0666666666666667*exp(0.133333333333333*I*pi), 0.133333333333333*exp(0.266666666666667*I*pi), 0.2*exp(0.4*I*pi), 0.266666666666667*exp(0.533333333333333*I*pi), 0.333333333333333*exp(0.666666666666667*I*pi), 0.4*exp(0.8*I*pi), 0.466666666666667*exp(0.933333333333333*I*pi), 0.533333333333333*exp(1.06666666666667*I*pi), 0.6*exp(1.2*I*pi), 0.666666666666667*exp(1.33333333333333*I*pi), 0.733333333333333*exp(1.46666666666667*I*pi), 0.8*exp(1.6*I*pi), 0.866666666666667*exp(1.73333333333333*I*pi), 0.933333333333333*exp(1.86666666666667*I*pi))
        [1]: complex points (0, 0.133333333333333*exp(0.133333333333333*I*pi), 0.266666666666667*exp(0.266666666666667*I*pi), 0.4*exp(0.4*I*pi), 0.533333333333333*exp(0.533333333333333*I*pi), 0.666666666666667*exp(0.666666666666667*I*pi), 0.8*exp(0.8*I*pi), 0.933333333333333*exp(0.933333333333333*I*pi), 1.06666666666667*exp(1.06666666666667*I*pi), 1.2*exp(1.2*I*pi), 1.33333333333333*exp(1.33333333333333*I*pi), 1.46666666666667*exp(1.46666666666667*I*pi), 1.6*exp(1.6*I*pi), 1.73333333333333*exp(1.73333333333333*I*pi), 1.86666666666667*exp(1.86666666666667*I*pi))
 
+    Interactive-widget plot. Refer to ``iplot`` documentation to learn more
+    about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       z, u = symbols("z u")
+       expr1 = z * exp(2 * pi * I * z)
+       expr2 = u * expr1
+       n = 15
+       l1 = [expr1.subs(z, t / n) for t in range(n)]
+       l2 = [expr2.subs(z, t / n) for t in range(n)]
+       plot_complex_list(
+           (l1, "f1"), (l2, "f2"),
+           params={u: (0.5, 0, 2)},
+           xlim=(-1.5, 2), ylim=(-2, 1))
+
+
     See Also
     ========
 
-    plot_real_imag, plot_complex, plot_complex_vector
+    plot_real_imag, plot_complex, plot_complex_vector, iplot
 
     """
     kwargs["absarg"] = False
@@ -1034,6 +1140,12 @@ def plot_complex_vector(*args, **kwargs):
         Number of discretization points for the scalar contour plot.
         Default to 100.
 
+    params : dict
+        A dictionary mapping symbols to parameters. This keyword argument
+        enables the interactive-widgets plot, which doesn't support the
+        adaptive algorithm (meaning it will use ``adaptive=False``).
+        Learn more by reading the documentation of ``iplot``.
+
     quiver_kw : dict
         A dictionary of keywords/values which is passed to the backend
         quivers-plotting function to customize the appearance. Refer to the
@@ -1161,10 +1273,23 @@ def plot_complex_vector(*args, **kwargs):
        [0]: 2D vector series: [(re(_x) - im(_y))**2 - (re(_y) + im(_x))**2, 2*(re(_x) - im(_y))*(re(_y) + im(_x))] over (_x, -5.0, 5.0), (_y, -5.0, 0.0)
        [1]: 2D vector series: [(re(_x) - im(_y))**3 - 3*(re(_x) - im(_y))*(re(_y) + im(_x))**2, 3*(re(_x) - im(_y))**2*(re(_y) + im(_x)) - (re(_y) + im(_x))**3] over (_x, -5.0, 5.0), (_y, 0.0, 5.0)
 
+    Interactive-widget plot. Refer to ``iplot`` documentation to learn more
+    about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       z, u = symbols("z u")
+       plot_complex_vector(
+           log(gamma(u * z)), (z, -5 - 5j, 5 + 5j),
+           params={u: (1, 0, 2)}, n=20,
+           quiver_kw=dict(color="orange"), grid=False)
+
     See Also
     ========
 
-    plot_real_imag, plot_complex, plot_complex_list
+    plot_real_imag, plot_complex, plot_complex_list, plot_vector, iplot
 
     """
     # for each argument, generate two series: one for the real part and
@@ -1175,8 +1300,10 @@ def plot_complex_vector(*args, **kwargs):
     kwargs["real"] = True
     kwargs["imag"] = True
     kwargs["threed"] = False
+    global_labels = kwargs.pop("labels", [])
 
     args = _plot_sympify(args)
+    params = kwargs.get("params", None)
     series = _build_series(*args, **kwargs)
     multiple_expr = len(series) > 2
 
@@ -1187,6 +1314,8 @@ def plot_complex_vector(*args, **kwargs):
                 return t
         return str(args[i][0] if multiple_expr else args[0])
 
+    for s in series:
+        print(s)
     # create new arguments to be used by plot_vector
     new_args = []
     x, y = symbols("x, y", cls=Dummy)
@@ -1195,7 +1324,10 @@ def plot_complex_vector(*args, **kwargs):
         s2 = series[2 * i + 1]
         expr1 = s1.expr
         expr2 = s2.expr
-        free_symbols = list(expr1.free_symbols)
+        free_symbols = expr1.free_symbols
+        if params is not None:
+            free_symbols = free_symbols.difference(params.keys())
+        free_symbols = list(free_symbols)
         if len(free_symbols) > 0:
             fs = free_symbols[0]
             expr1 = expr1.subs({fs: x + I * y})
@@ -1215,6 +1347,7 @@ def plot_complex_vector(*args, **kwargs):
             scalar[0] = scalar[0].subs({fs: x + I * y})
         kwargs["scalar"] = scalar
 
+    kwargs["labels"] = global_labels
     kwargs.setdefault("xlabel", "x")
     kwargs.setdefault("ylabel", "y")
     return plot_vector(*new_args, **kwargs)
