@@ -1,14 +1,11 @@
-from sympy.printing.latex import latex
-from sympy.core.containers import Tuple
-from sympy.external import import_module
-from spb.series import (
-    InteractiveSeries,
-    _set_discretization_points,
-)
-from spb.ccomplex.complex import _build_series as _build_complex_series
-from spb.vectors import _preprocess, _build_series as _build_vector_series
-from spb.utils import _plot_sympify, _unpack_args
 from spb.defaults import TWO_D_B, THREE_D_B, cfg
+from spb.ccomplex.complex import _build_series as _build_complex_series
+from spb.functions import _set_labels
+from spb.series import InteractiveSeries, _set_discretization_points
+from spb.vectors import _preprocess, _build_series as _build_vector_series
+from spb.utils import _plot_sympify, _unpack_args_extended
+from sympy import latex, Tuple
+from sympy.external import import_module
 import warnings
 
 param = import_module(
@@ -226,8 +223,11 @@ class DynamicParam(param.Parameterized):
     @param.depends("check_val", watch=True)
     def update(self):
         params = self.read_parameters()
-        self._backend._update_interactive(params)
-        self._action_post_update()
+        # NOTE: in case _backend is not an attribute, it means that this
+        # class has been instantiated by create_widgets
+        if hasattr(self, "_backend"):
+            self._backend._update_interactive(params)
+            self._action_post_update()
 
 
 def _new_class(cls, **kwargs):
@@ -615,10 +615,10 @@ def create_series(*args, **kwargs):
     if is_complex:
         new_args = []
         for a in args:
-            exprs, ranges, label = _unpack_args(
+            exprs, ranges, label, rkw = _unpack_args_extended(
                 *a, matrices=False, fill_ranges=False
             )
-            new_args.append(Tuple(exprs[0], *ranges, label, sympify=False))
+            new_args.append(Tuple(exprs[0], *ranges, label, rkw, sympify=False))
         series = _build_complex_series(*new_args, interactive=True, **kwargs)
     elif is_vector:
         args = _preprocess(*args, matrices=False, fill_ranges=False)
@@ -630,9 +630,10 @@ def create_series(*args, **kwargs):
             # fill_ranges=False in order to not fill ranges, otherwise
             # ranges will be created also for parameters. This means
             # the user must provided all the necessary ranges.
-            exprs, ranges, label = _unpack_args(
+            exprs, ranges, label, rkw = _unpack_args_extended(
                 *a, matrices=True, fill_ranges=False
             )
+            kwargs["rendering_kw"] = rkw
             if isinstance(_slice, (tuple, list)):
                 # Sliced 3D vector field: each slice creates a
                 # unique series
@@ -683,8 +684,15 @@ class InteractivePlot(DynamicParam, PanelLayout):
         super().__init__(*args, name=self._name, params=params, use_latex=use_latex)
         PanelLayout.__init__(self, layout, ncols, throttled, servable, custom_css, pane_kw)
 
-        # create the series
+        # create the series and apply the global labels and rendering keywords
+        labels = kwargs.pop("label", [])
+        rendering_kw = kwargs.pop("rendering_kw", None)
         series = create_series(*args, iplot=self, **kwargs)
+        _set_labels(series, labels, rendering_kw)
+
+        if kwargs.get("is_complex", False):
+            from spb.ccomplex.complex import _set_axis_labels
+            _set_axis_labels(series, kwargs)
         is_3D = all([s.is_3D for s in series])
         # create the plot
         Backend = kwargs.pop("backend", THREE_D_B if is_3D else TWO_D_B)
@@ -763,8 +771,15 @@ class InteractivePlot(DynamicParam, PanelLayout):
 
 
 def iplot(*args, show=True, **kwargs):
-    """
-    Create interactive plots of symbolic expressions.
+    """Create interactive-widget plots of symbolic expressions.
+
+    Note that this function is already integrated with many of the usual
+    plotting functions, hence it is recommended to use those instead of
+    ``iplot`` because their documentation is more specific.
+
+    However, the following documentation explains in details the main features
+    exposed by the interactive module, which might not be included on the
+    documentation of those other functions.
 
     Parameters
     ==========
@@ -837,6 +852,11 @@ def iplot(*args, show=True, **kwargs):
 
         For surface plots, the coloring is applied only if ``use_cm=True``.
 
+    label : list/tuple, optional
+        The labels to be shown in the legend. If not provided, the string
+        representation of `expr` will be used. The number of labels must be
+        equal to the number of series generated by the plotting function.
+
     layout : str, optional
         The layout for the controls/plot. Possible values:
 
@@ -866,6 +886,13 @@ def iplot(*args, show=True, **kwargs):
         served on a new browser window. Refer to ``servable`` to learn more.
         Default to an empty string.
 
+    rendering_kw : dict or list of dicts, optional
+        A dictionary of keywords/values which is passed to the backend's
+        function to customize the appearance of lines, surfaces, etc.
+        Refer to the plotting library (backend) manual for more informations.
+        If a list of dictionaries is provided, the number of dictionaries must
+        be equal to the number of series generated by the plotting function.
+
     servable : bool, optional
         Default to False, which will show the interactive application on the
         output cell of a Jupyter Notebook. If True, the application will be
@@ -972,10 +999,11 @@ def iplot(*args, show=True, **kwargs):
 
     1. some expression may not use all the parameters.
     2. custom labeling of the expressions.
-    3. custom number of steps in the slider.
-    4. custom format of the value shown on the slider. This might be useful to
+    3. custom rendering of the expressions.
+    4. custom number of steps in the slider.
+    5. custom format of the value shown on the slider. This might be useful to
        correctly visualize very small or very big numbers.
-    5. custom labeling of the parameter-sliders.
+    6. custom labeling of the parameter-sliders.
 
     .. jupyter-execute::
 
@@ -985,8 +1013,8 @@ def iplot(*args, show=True, **kwargs):
        G = kp / (I**2 * t**2 * o**2 + 2 * z * t * o * I + 1)
        mod = lambda x: 20 * log(sqrt(re(x)**2 + im(x)**2), 10)
        iplot(
-           (mod(G.subs(z, 0)), (o, 0.1, 100), "G(z=0)"),
-           (mod(G.subs(z, 1)), (o, 0.1, 100), "G(z=1)"),
+           (mod(G.subs(z, 0)), (o, 0.1, 100), "G(z=0)", {"line_dash": "dotted"}),
+           (mod(G.subs(z, 1)), (o, 0.1, 100), "G(z=1)", {"line_dash": "dotted"}),
            (mod(G), (o, 0.1, 100), "G"),
            params = {
                kp: (1, 0, 3),
@@ -1001,8 +1029,8 @@ def iplot(*args, show=True, **kwargs):
            use_latex = False
        )
 
-    A line plot with a parameters representing an angle in radians, but
-    showing the value in the label in degrees:
+    A line plot with a parameter representing an angle in radians, but
+    showing the value in degrees on its label:
 
     .. jupyter-execute::
 
@@ -1057,7 +1085,6 @@ def iplot(*args, show=True, **kwargs):
            use_latex = False
        )
 
-
     A parametric plot of a symbolic polygon. Note the use of `param` to create
     an integer slider.
 
@@ -1119,10 +1146,9 @@ def iplot(*args, show=True, **kwargs):
            title = "title 2",
            show = False
        )
-       p3 = plot(sin(x)*cos(x), (x, -5, 5), backend=MB,
+       p3 = plot(sin(x)*cos(x), (x, -5, 5), dict(marker="^"), backend=MB,
            adaptive=False, n=50,
-           is_point=True, is_filled=True,
-           line_kw=dict(marker="^"), show=False)
+           is_point=True, is_filled=True, show=False)
        p = p1 + p2 + p3
        p.show()
 
@@ -1163,11 +1189,10 @@ def iplot(*args, show=True, **kwargs):
     =====
 
     1. This function is specifically designed to work within Jupyter Notebook.
-       However, it is also possible to use it from a regular Python, by
-       executing: ``iplot(..., servable=True)``,
-       which will create a server process loading the interactive plot on
-       the browser. However, ``K3DBackend`` is not supported in this mode of
-       operation.
+       However, it is also possible to use it from a regular Python console,
+       by executing: ``iplot(..., servable=True)``, which will create a server
+       process loading the interactive plot on the browser.
+       However, ``K3DBackend`` is not supported in this mode of operation.
 
     2. Some examples use an instance of ``PrintfTickFormatter`` to format the
        value shown by a slider. This class is exposed by Bokeh, but can be
