@@ -1,9 +1,5 @@
 from spb.defaults import cfg
-from sympy.core.containers import Tuple
-from sympy.core.sympify import sympify
-from sympy.core.expr import Expr
-from sympy.core.symbol import Dummy
-from sympy.core.singleton import S
+from sympy import Tuple, sympify, Expr, Dummy, S
 from sympy.matrices.dense import DenseMatrix
 from sympy.vector import Vector
 from sympy.vector.operators import _get_coord_systems
@@ -12,7 +8,7 @@ from sympy.logic.boolalg import BooleanFunction
 from sympy.external import import_module
 
 
-def _create_ranges(free_symbols, ranges, npar):
+def _create_ranges(exprs, ranges, npar, label="", params=None):
     """This function does two things:
     1. Check if the number of free symbols is in agreement with the type of
        plot chosen. For example, plot() requires 1 free symbol;
@@ -20,20 +16,30 @@ def _create_ranges(free_symbols, ranges, npar):
     2. Sometime users create plots without providing ranges for the variables.
        Here we create the necessary ranges.
 
-    free_symbols
-        The free symbols contained in the expressions to be plotted
+    Parameters
+    ==========
 
-    ranges
+    exprs : iterable
+        The expressions from which to extract the free symbols
+
+    ranges : iterable
         The limiting ranges provided by the user
 
-    npar
+    npar : int
         The number of free symbols required by the plot functions.
         For example,
         npar=1 for plot, npar=2 for plot3d, ...
 
+    params : dict
+        A dictionary mapping symbols to parameters for iplot.
+
     """
 
     get_default_range = lambda symbol: Tuple(symbol, cfg["plot_range"]["min"], cfg["plot_range"]["max"])
+    free_symbols = set().union(*[e.free_symbols for e in exprs])
+
+    if params is not None:
+        free_symbols = free_symbols.difference(params.keys())
 
     if len(free_symbols) > npar:
         raise ValueError(
@@ -76,7 +82,29 @@ def _create_ranges(free_symbols, ranges, npar):
     return ranges
 
 
-def _check_arguments(args, nexpr, npar):
+def _check_interactive_fs(exprs, ranges, label, params):
+    """ Checks if there are enogh parameters and free symbols in order to
+    build the interactive series.
+    """
+    # from the expression's free symbols, remove the ones used in
+    # the parameters and the ranges
+    fs = set().union(*[e.free_symbols for e in exprs])
+    fs = fs.difference(params.keys())
+    if ranges is not None:
+        fs = fs.difference([r[0] for r in ranges])
+
+    if len(fs) > 0:
+        raise ValueError(
+            "Incompatible expression and parameters.\n"
+            + "Expression: {}\n".format(
+                (exprs, ranges, label) if ranges is not None else (exprs, label))
+            + "params: {}\n".format(params)
+            + "Specify what these symbols represent: {}\n".format(fs)
+            + "Are they ranges or parameters?"
+        )
+
+
+def _check_arguments(args, nexpr, npar, **kwargs):
     """Checks the arguments and converts into tuples of the
     form (exprs, ranges, name_expr).
 
@@ -120,25 +148,16 @@ def _check_arguments(args, nexpr, npar):
     if not args:
         return []
     output = []
+    params = kwargs.get("params", None)
 
     if all([isinstance(a, (Expr, Relational, BooleanFunction)) for a in args[:nexpr]]):
         # In this case, with a single plot command, we are plotting either:
         #   1. one expression
         #   2. multiple expressions over the same range
 
-        res = [not (_is_range(a) or isinstance(a, str)) for a in args]
-        exprs = [a for a, b in zip(args, res) if b]
-        ranges = [r for r in args[nexpr:] if _is_range(r)]
-        label = args[-1] if isinstance(args[-1], str) else ""
-
-        if not all([_is_range(r) for r in ranges]):
-            raise ValueError(
-                "Expressions must be followed by ranges. Received:\n"
-                "Expressions: %s\n"
-                "Others: %s" % (exprs, ranges)
-            )
+        exprs, ranges, label, rendering_kw = _unpack_args(*args)
         free_symbols = set().union(*[e.free_symbols for e in exprs])
-        ranges = _create_ranges(free_symbols, ranges, npar)
+        ranges = _create_ranges(exprs, ranges, npar, label, params)
 
         if nexpr > 1:
             # in case of plot_parametric or plot3d_parametric_line, there will
@@ -148,44 +167,38 @@ def _check_arguments(args, nexpr, npar):
         for expr in exprs:
             # need this if-else to deal with both plot/plot3d and
             # plot_parametric/plot3d_parametric_line
-            e = (
-                (expr,)
-                if isinstance(expr, (Expr, Relational, BooleanFunction))
-                else expr
-            )
+            is_expr = isinstance(expr, (Expr, Relational, BooleanFunction))
+            e = (expr,) if is_expr else expr
             current_label = (
-                label
-                if label
-                else (
-                    str(expr)
-                    if isinstance(expr, (Expr, Relational, BooleanFunction))
-                    else str(e)
-                )
+                label if label else str(expr) if is_expr else str(e)
             )
             if ((not label) and (current_label != label) and
                 (nexpr in [2, 3]) and (npar == 1)):
                 # in case of parametric 2d/3d line plots, use the parameter
                 # as the label
                 current_label = str(ranges[0][0])
-            output.append((*e, *ranges, current_label))
+            output.append((*e, *ranges, current_label, rendering_kw))
 
     else:
         # In this case, we are plotting multiple expressions, each one with its
         # range. Each "expression" to be plotted has the following form:
         # (expr, range, label) where label is optional
 
-        # look for "global" range and label
-        labels = [a for a in args if isinstance(a, str)]
-        ranges = [a for a in args if _is_range(a)]
-        n = len(ranges) + len(labels)
+        _, ranges, labels, rendering_kw = _unpack_args(*args)
+        labels = [labels] if labels else []
+
+        # number of expressions
+        n = (len(ranges) + len(labels) +
+            (len(rendering_kw) if rendering_kw is not None else 0))
         new_args = args[:-n] if n > 0 else args
+
         # at this point, new_args might just be [expr]. But I need it to be
         # [[expr]] in order to be able to loop over [expr, range [opt], label [opt]]
         if not isinstance(new_args[0], (list, tuple, Tuple)):
             new_args = [new_args]
 
         # Each arg has the form (expr1, expr2, ..., range1 [optional], ...,
-        #   label [optional])
+        #   label [optional], rendering_kw [optional])
         for arg in new_args:
             # look for "local" range and label. If there is not, use "global".
             l = [a for a in arg if isinstance(a, str)]
@@ -194,11 +207,13 @@ def _check_arguments(args, nexpr, npar):
             r = [a for a in arg if _is_range(a)]
             if not r:
                 r = ranges.copy()
+            rend_kw = [a for a in arg if isinstance(a, dict)]
+            rend_kw = rendering_kw if len(rend_kw) == 0 else rend_kw[0]
 
             arg = arg[:nexpr]
             free_symbols = set().union(*[a.free_symbols for a in arg])
             if len(r) != npar:
-                r = _create_ranges(free_symbols, r, npar)
+                r = _create_ranges(arg, r, npar, "", params)
             label = ""
             if not l:
                 label = str(arg[0]) if nexpr == 1 else str(arg)
@@ -208,7 +223,7 @@ def _check_arguments(args, nexpr, npar):
                     label = str(r[0][0])
             else:
                 label = l[0]
-            output.append((*arg, *r, label))
+            output.append((*arg, *r, label, rend_kw))
     return output
 
 
@@ -227,10 +242,8 @@ def _plot_sympify(args):
     for i, a in enumerate(args):
         if isinstance(a, (list, tuple)):
             args[i] = Tuple(*_plot_sympify(a), sympify=False)
-        elif not isinstance(a, str):
+        elif not isinstance(a, (str, dict)):
             args[i] = sympify(a)
-    if isinstance(args, tuple):
-        return Tuple(*args, sympify=False)
     return args
 
 
@@ -241,26 +254,15 @@ def _is_range(r):
     return (
         isinstance(r, Tuple)
         and (len(r) == 3)
-        and r.args[1].is_number
-        and r.args[2].is_number
+        and (not isinstance(r.args[1], str)) and r.args[1].is_number
+        and (not isinstance(r.args[2], str)) and r.args[2].is_number
     )
 
 
-def _unpack_args(*args, matrices=False, fill_ranges=True):
-    """Given a list/tuple of arguments previously processed by _plot_sympify(),
-    separates and returns its components: expressions, ranges, label.
-
-    Parameters
-    ==========
-        matrices : boolean
-            Default to False. If True, when a single DenseMatrix is given as
-            the expression, it will be converted to a list. This is useful in
-            order to deal with vectors (written in form of matrices) for
-            iplot.
-
-        fill_ranges : boolean
-            Default to True. If not enough ranges are provided, the algorithm
-            will try to create the missing ones.
+def _unpack_args(*args):
+    """Given a list/tuple of arguments previously processed by _plot_sympify()
+    and/or _check_arguments(), separates and returns its components:
+    expressions, ranges, label and rendering keywords.
 
     Examples
     ========
@@ -285,8 +287,35 @@ def _unpack_args(*args, matrices=False, fill_ranges=True):
     ranges = [t for t in args if _is_range(t)]
     labels = [t for t in args if isinstance(t, str)]
     label = "" if not labels else labels[0]
-    results = [not (_is_range(a) or isinstance(a, str)) for a in args]
+    rendering_kw = [t for t in args if isinstance(t, dict)]
+    rendering_kw = None if not rendering_kw else rendering_kw[0]
+    # NOTE: why None? because args might have been preprocessed by
+    # _check_arguments, so None might represent the rendering_kw
+    results = [not (_is_range(a) or isinstance(a, (str, dict)) or (a is None)) for a in args]
     exprs = [a for a, b in zip(args, results) if b]
+    return exprs, ranges, label, rendering_kw
+
+
+def _unpack_args_extended(*args, matrices=False, fill_ranges=True):
+    """Extendend _unpack_args to deal with vectors expressed as matrices.
+
+    Parameters
+    ==========
+    matrices : boolean
+        Default to False. If True, when a single DenseMatrix is given as
+        the expression, it will be converted to a list. This is useful in
+        order to deal with vectors (written in form of matrices) for
+        iplot.
+
+    fill_ranges : boolean
+        Default to True. If not enough ranges are provided, the algorithm
+        will try to create the missing ones.
+
+    See also
+    ========
+    _unpack_args
+    """
+    exprs, ranges, label, rendering_kw = _unpack_args(*args)
 
     if label == "":
         if len(exprs) == 1:
@@ -301,7 +330,7 @@ def _unpack_args(*args, matrices=False, fill_ranges=True):
             exprs, ranges = _split_vector(exprs[0], ranges, fill_ranges)
             if exprs[-1] is S.Zero:
                 exprs = exprs[:-1]
-    return exprs, ranges, label
+    return exprs, ranges, label, rendering_kw
 
 
 def ij2k(cols, i, j):
@@ -388,3 +417,10 @@ def _split_vector(expr, ranges, fill_ranges=True):
         xexpr, yexpr, zexpr = expr
     split_expr = xexpr, yexpr, zexpr
     return split_expr, ranges
+
+
+def _instantiate_backend(Backend, *series, **kwargs):
+    p = Backend(*series, **kwargs)
+    if kwargs.get("show", True):
+        p.show()
+    return p
