@@ -1,21 +1,16 @@
 from spb.defaults import TWO_D_B, THREE_D_B, cfg
 from spb.functions import _set_labels
 from spb.series import (
-    BaseSeries,
-    Vector2DSeries,
-    Vector3DSeries,
-    ContourSeries,
-    SliceVector3DSeries,
-    _set_discretization_points,
-    InteractiveSeries
+    BaseSeries, Vector2DSeries, Vector3DSeries, ContourSeries,
+    SliceVector3DSeries, InteractiveSeries, _set_discretization_points
+)
+from spb.utils import (
+    _plot_sympify, _unpack_args_extended, _split_vector, _is_range,
+    _instantiate_backend
+)
+from sympy import (
+    MutableDenseMatrix, ImmutableDenseMatrix, Tuple, sqrt, Expr, S, Plane
 )
-from spb.utils import _plot_sympify, _unpack_args, _split_vector, _is_range
-from sympy import MutableDenseMatrix, ImmutableDenseMatrix
-from sympy.core.containers import Tuple
-from sympy.functions.elementary.miscellaneous import sqrt
-from sympy.core.expr import Expr
-from sympy.core.singleton import S
-from sympy.geometry import Plane
 
 
 def _build_series(*args, interactive=False, **kwargs):
@@ -233,7 +228,8 @@ def _preprocess(*args, matrices=False, fill_ranges=True):
     following form: [expr, *ranges, label].
     `expr` can be a vector, a matrix or a list/tuple/Tuple.
 
-    `matrices` and `fill_ranges` are going to be passed to `_unpack_args`.
+    `matrices` and `fill_ranges` are going to be passed to
+    `_unpack_args_extended`.
     """
     if not all([isinstance(a, (list, tuple, Tuple)) for a in args]):
         # In this case we received arguments in one of the following forms.
@@ -248,7 +244,7 @@ def _preprocess(*args, matrices=False, fill_ranges=True):
 
     new_args = []
     for a in args:
-        exprs, ranges, label = _unpack_args(
+        exprs, ranges, label, rendering_kw = _unpack_args_extended(
             *a, matrices=matrices, fill_ranges=fill_ranges
         )
         if len(exprs) == 1:
@@ -262,7 +258,7 @@ def _preprocess(*args, matrices=False, fill_ranges=True):
     return new_args
 
 
-def plot_vector(*args, show=True, **kwargs):
+def plot_vector(*args, **kwargs):
     """
     Plot a 2D or 3D vector field. By default, the aspect ratio of the plot
     is set to `aspect="equal"`.
@@ -273,7 +269,7 @@ def plot_vector(*args, show=True, **kwargs):
         `plot(expr, range1, range2, range3 [optional], **kwargs)`
 
     - Plotting multiple vector fields with different ranges and custom labels.
-        `plot((expr1, range1, range2, range3 [optional], label1), (expr2, range4, range5, range6 [optional], label2), **kwargs)`
+        `plot((expr1, range1, range2, range3 [optional], label1 [optional]), (expr2, range4, range5, range6 [optional], label2 [optional]), **kwargs)`
 
     Parameters
     ==========
@@ -292,9 +288,9 @@ def plot_vector(*args, show=True, **kwargs):
             ranges are needed.
 
         label : str, optional
-            The name of the vector field to be eventually shown on the legend.
-            If none is provided, the string representation of the vector will
-            be used.
+            The name of the vector field to be eventually shown on the legend
+            or colorbar. If none is provided, the string representation of
+            the vector will be used.
 
     aspect : (float, float) or str, optional
         Set the aspect ratio of the plot. The value depends on the backend
@@ -310,9 +306,11 @@ def plot_vector(*args, show=True, **kwargs):
         contour function to customize the appearance. Refer to the plotting
         library (backend) manual for more informations.
 
-    label : str or list/tuple, optional
+    label : list/tuple, optional
         The label to be shown in the colorbar if ``scalar=None``.
         If not provided, the string representation of `expr` will be used.
+        The number of labels must be equal to the number of series generated
+        by the plotting function.
 
     n1, n2, n3 : int
         Number of discretization points for the quivers or streamlines in the
@@ -327,6 +325,12 @@ def plot_vector(*args, show=True, **kwargs):
         Number of discretization points for the scalar contour plot.
         Default to 100.
 
+    params : dict
+        A dictionary mapping symbols to parameters. This keyword argument
+        enables the interactive-widgets plot, which doesn't support the
+        adaptive algorithm (meaning it will use ``adaptive=False``).
+        Learn more by reading the documentation of ``iplot``.
+
     quiver_kw : dict
         A dictionary of keywords/values which is passed to the backend quivers-
         plotting function to customize the appearance. Refer to the plotting
@@ -447,7 +451,9 @@ def plot_vector(*args, show=True, **kwargs):
        :include-source: True
 
        >>> plot_vector([-sin(y), cos(x)], (x, -3, 3), (y, -3, 3),
-       ...     quiver_kw=dict(color="black"), grid=False)
+       ...     quiver_kw=dict(color="black"),
+       ...     contour_kw={"cmap": "Blues_r", "levels": 20},
+       ...     grid=False)
        Plot object containing:
        [0]: contour: sqrt(sin(y)**2 + cos(x)**2) for x over (-3.0, 3.0) and y over (-3.0, 3.0)
        [1]: 2D vector series: [-sin(y), cos(x)] over (x, -3.0, 3.0), (y, -3.0, 3.0)
@@ -483,6 +489,22 @@ def plot_vector(*args, show=True, **kwargs):
        [1]: 2D vector series: [-sin(y), cos(x)] over (x, -5.0, 5.0), (y, -3.0, 3.0)
        [2]: 2D vector series: [y, x] over (x, -5.0, 5.0), (y, -3.0, 3.0)
 
+    Interactive-widget 2D vector plot. Refer to ``iplot`` documentation to
+    learn more about the ``params`` dictionary.
+
+    .. code-block:: python
+
+       from sympy import *
+       from spb import *
+       x, y, u = symbols("x y u")
+       plot_vector(
+           [-sin(u * y), cos(x)], (x, -3, 3), (y, -3, 3),
+           params={u: (1, 0, 2)},
+           n=20,
+           quiver_kw=dict(color="black"),
+           contour_kw={"cmap": "Blues_r", "levels": 20},
+           grid=False)
+
     3D vector field.
 
     .. plot::
@@ -531,15 +553,30 @@ def plot_vector(*args, show=True, **kwargs):
        ...     xlabel="x", ylabel="y", zlabel="z")
        Plot object containing:
        [0]: 3D vector series: [z, y, x] over (x, -10.0, 10.0), (y, -10.0, 10.0), (z, -10.0, 10.0)
+
+    See Also
+    ========
+
+    iplot
+
     """
     args = _plot_sympify(args)
     args = _preprocess(*args)
 
     labels = kwargs.pop("label", [])
+    rendering_kw = kwargs.pop("rendering_kw", None)
     kwargs = _set_discretization_points(kwargs, Vector3DSeries)
     kwargs.setdefault("aspect", "equal")
     kwargs.setdefault("legend", True)
 
+    params = kwargs.get("params", None)
+    is_interactive = False if params is None else True
+    kwargs["is_interactive"] = is_interactive
+    if is_interactive:
+        from spb.interactive import iplot
+        kwargs["is_vector"] = True
+        return iplot(*args, **kwargs)
+
     series = _build_series(*args, **kwargs)
     if all([isinstance(s, (Vector2DSeries, ContourSeries)) for s in series]):
         Backend = kwargs.pop("backend", TWO_D_B)
@@ -548,8 +585,5 @@ def plot_vector(*args, show=True, **kwargs):
     else:
         raise ValueError("Mixing 2D vectors with 3D vectors is not allowed.")
 
-    _set_labels(series, labels)
-    p = Backend(*series, **kwargs)
-    if show:
-        p.show()
-    return p
+    _set_labels(series, labels, rendering_kw)
+    return _instantiate_backend(Backend, *series, **kwargs)
